@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/Xm/Xm.h.in,v 1.31 2002/04/26 20:37:39 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/Xm/Xm.h.in,v 1.33 2002/09/10 22:09:13 dannybackx Exp $
  *
  * Copyright  1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -46,7 +46,7 @@
 #define LESSTIF_REVISION 93
 
 #define LesstifVersion (LESSTIF_VERSION * 1000 + LESSTIF_REVISION)
-#define LesstifVERSION_STRING "@(#)GNU/LessTif Version 2.1 Release 0.93.34"
+#define LesstifVERSION_STRING "@(#)GNU/LessTif Version 2.1 Release 0.93.40"
 
 /* since we're replacing Motif 2.1... */
 #define XmVERSION 2
@@ -142,7 +142,9 @@ enum {
 
 typedef enum {
     XmFONT_IS_FONT,
-    XmFONT_IS_FONTSET
+    XmFONT_IS_FONTSET,
+    XmFONT_IS_XOC,	/* IBM's BiDi extension to Motif */
+    XmFONT_IS_XFT	/* FontConfig */
 } XmFontType;
 
 enum {
@@ -435,6 +437,9 @@ enum {
     XmALIGNMENT_WIDGET_BOTTOM
 };
 
+#define XmALIGNMENT_CHILD_TOP XmALIGNMENT_WIDGET_BOTTOM
+#define XmALIGNMENT_CHILD_BOTTOM XmALIGNMENT_WIDGET_TOP 
+
 /* Frame Child Types */
 
 enum {
